Index: views/widget/widget_delegate.h |
=================================================================== |
--- views/widget/widget_delegate.h (revision 98697) |
+++ views/widget/widget_delegate.h (working copy) |
@@ -10,7 +10,6 @@ |
#include "base/memory/scoped_ptr.h" |
#include "ui/base/accessibility/accessibility_types.h" |
-#include "ui/base/ui_base_types.h" |
#include "views/view.h" |
class SkBitmap; |
@@ -98,16 +97,15 @@ |
// state restoration. |
virtual std::wstring GetWindowName() const; |
// Saves the window's bounds and "show" state. By default this uses the |
// process' local state keyed by window name (See GetWindowName above). This |
// behavior can be overridden to provide additional functionality. |
- virtual void SaveWindowPlacement(const gfx::Rect& bounds, |
- ui::WindowShowState show_state); |
+ virtual void SaveWindowPlacement(const gfx::Rect& bounds, bool maximized); |
- // Retrieves the window's bounds and "show" states. |
+ // Retrieves the window's bounds and maximized states. |
// This behavior can be overridden to provide additional functionality. |
- virtual bool GetSavedWindowPlacement(gfx::Rect* bounds, |
- ui::WindowShowState* show_state) const; |
+ virtual bool GetSavedWindowBounds(gfx::Rect* bounds) const; |
+ virtual bool GetSavedMaximizedState(bool* maximized) const; |
// Returns true if the window's size should be restored. If this is false, |
// only the window's origin is restored and the window is given its |
Property changes on: views/widget/widget_delegate.h |
@@ -98,16 +97,15 @@ |
// state restoration. |
virtual std::wstring GetWindowName() const; |
- // Saves the window's bounds and "show" state. By default this uses the |
+ // Saves the window's bounds and maximized states. By default this uses the |
// process' local state keyed by window name (See GetWindowName above). This |
// behavior can be overridden to provide additional functionality. |
___________________________________________________________________ |
Added: svn:mergeinfo |